# GoodGame
A Simple API for making games
# Installing
```commandline
python -m pip install goodgame
```
Note, you may use `python3` instead of `python`
# Documentation
 - See [here](https://github.com/Pyxelsuft/goodgame/tree/main/docs)
# Examples
 - Test [here](main.py) <br />
 - Also [here](https://github.com/PixelsuftGames/good-examples)
 - Also [here](https://youtu.be/dQw4w9WgXcQ)
# TODO
 - See [here](https://github.com/Pyxelsuft/goodgame/search?q=TODO&type=)
